<section class="content-header word-wrap">
  <h1>
    Version Manager
      <small>for {{ data.object_name }} <b>{{data.version_manager.title }}</b></small>
  </h1>
</section>

<section class="content">
    <div class="row">
        <div class="col-md-12">
            {% block list_includes %}
            {% include 'core_user_registration_app/admin/templates/versions/available.html' %}
            {% if not data.version_manager.user %}
                {% include 'core_main_app/admin/templates/versions/disabled.html' %}
            {% endif %}
            {% endblock %}
        </div>
    </div>
</section>

