{% load i18n %}
<h3><span>Please provide us with this additional information</span></h3>

<div class="toolbar">
    <br/><br/>

    <div id = "data_username" class = "hidden" >
    {{data.account_creation.username}}
    </div>
    <div id = "data_first_name" class = "hidden" >
    {{data.account_creation.first_name}}
    </div>
    <div id = "data_last_name" class = "hidden" >
    {{data.account_creation.last_name}}
    </div>
    <div id = "data_email" class = "hidden" >
    {{data.account_creation.email}}
    </div>
    <div id="account_request_id" style="display: none;">{{ data.account_id }}</div>

    <div id="curate_data_structure_id" style="display: none;">{{ data.data_structure.id }}</div>
    <div id="xsdForm" class="xsdForm">
        {{data.xsd_form|safe}}
    </div>
    <div class="form-group">
    <div class="col-sm-12">
        <a class="btn btn-default save-to-repo">
            <i class="fas fa-arrow-right"></i> Finish Registration
        </a>
    </div>
    </div>
</div>

