{% extends "core_main_app/_render/admin/theme/tools/section.html" %}
{% load static %}

{% block section_title %}Account Requests{% endblock %}

{% block section_content %}
<div class="row">
    <div class="col-md-12">
        {% include "core_user_registration_app/admin/account_requests/pending.html" %}
    </div>
</div>
{% endblock %}